@@ -10,8 +10,8 @@
 #include <sysexits.h>
 #include <ctype.h>
 #include <pwd.h>
-#include <mail.h>
-#include <signal.h>
+#include "mail.h"
+#include "zmsignal.h"
 #ifdef FCNTL_H
 # include FCNTL_H
 #endif
@@ -293,12 +293,16 @@ otherprog:
 		perror(path);
 		exit(EX_UNAVAILABLE);
 	} else {	/* ahh, normal, at last! */
-		if (signal(SIGINT, SIG_IGN) != SIG_IGN)
-			signal(SIGINT, doabort);
-		if (signal(SIGTERM, SIG_IGN) != SIG_IGN)
-			signal(SIGTERM, doabort);
-		if (signal(SIGHUP, SIG_IGN) != SIG_IGN)
-			signal(SIGHUP, doabort);
+		SIGNAL_TYPE (*oldsig)();
+		SIGNAL_HANDLESAVE(SIGINT, SIG_IGN, oldsig);
+		if (oldsig != SIG_IGN)
+			SIGNAL_HANDLE(SIGINT, doabort);
+		SIGNAL_HANDLESAVE(SIGTERM, SIG_IGN, oldsig);
+		if (oldsig != SIG_IGN)
+			SIGNAL_HANDLE(SIGTERM, doabort);
+		SIGNAL_HANDLESAVE(SIGHUP, SIG_IGN, oldsig);
+		if (oldsig != SIG_IGN)
+			SIGNAL_HANDLE(SIGHUP, doabort);
 		/*
 		 * If running as root, run as the user who su'ed if applicable.
 		 * If still running as root, run as the trusted user.  If from
