@@ -1,6 +1,6 @@
 #include "hostenv.h"
 #include "mailer.h"
-#include <signal.h>
+#include "zmsignal.h"
 #include <fcntl.h>
 #include <sys/ioctl.h>
 #ifdef	USE_RLIMIT
@@ -35,13 +35,13 @@ detach()
 		goto out;
 	/* Ignore terminal stop signals */
 #ifdef	SIGTTOU
-	(void) signal(SIGTTOU, SIG_IGN);
+	SIGNAL_IGNORE(SIGTTOU);
 #endif	/* SIGTTOU */
 #ifdef	SIGTTIN
-	(void) signal(SIGTTIN, SIG_IGN);
+	SIGNAL_IGNORE(SIGTTIN);
 #endif	/* SIGTTIN */
 #ifdef	SIGTSTP
-	(void) signal(SIGTSTP, SIG_IGN);
+	SIGNAL_IGNORE(SIGTSTP);
 #endif	/* SIGTSTP */
 	/*
 	 * Allow parent shell to continue.
@@ -66,31 +66,31 @@ detach()
 #ifdef	USE_SETSID
 	if (fork() != 0)
 		exit(0);	/* setsid() can be called only once per proc. */
-	(void) setsid();
+	setsid();
 #else	/* !USE_SETSID */
 #ifdef	USE_BSDSETPGRP
 	if ((fd = open("/dev/tty", O_RDWR, 0)) >= 0) {
-		(void) ioctl(fd, TIOCNOTTY, 0);	/* lose controlling terminal */
-		(void) close(fd);
+		ioctl(fd, TIOCNOTTY, 0);	/* lose controlling terminal */
+		close(fd);
 	}
-	(void) setpgrp(0, getpid());	/* change process group */
+	setpgrp(0, getpid());	/* change process group */
 #else	/* !USE_BSDSETPGRP */
 	/* lose controlling terminal and change process group */
-	(void) setpgrp();
-	(void) signal(SIGHUP, SIG_IGN);	/* immune from pgrp leader death */
-	if (fork() != 0)		/* become non-pgrp-leader */
+	setpgrp();
+	SIGNAL_IGNORE(SIGHUP);	/* immune from pgrp leader death */
+	if (fork() != 0)	/* become non-pgrp-leader */
 		exit(0);	/* first child */
 	/* second child */
 #endif	/* USE_BSDSETPGRP */
 #endif	/* USE_SETSID */
 
 out:
-	(void) close(0);
+	close(0);
 #if	0
 	for (fd = 3; fd < getdtablesize(); ++fd)
-		(void) close(fd);	/* close almost all file descriptors */
+		close(fd);	/* close almost all file descriptors */
 #endif	/* notdef */
-	(void) umask(022); /* clear any inherited file mode creation mask */
+	umask(022); /* clear any inherited file mode creation mask */
 
 	/* Clean out our environment from personal contamination */
 	cleanenv();
@@ -100,7 +100,7 @@ out:
 	{	struct rlimit rl;
 		rl.rlim_cur = RLIM_INFINITY;
 		rl.rlim_max = RLIM_INFINITY;
-		(void) setrlimit(RLIMIT_CPU, &rl);
+		setrlimit(RLIMIT_CPU, &rl);
 	}
 #endif	/* USE_RLIMIT */
 	return;
