@@ -2556,7 +2556,7 @@ fapply(shcmdp, l)
 
 	if (shcmdp->sptr != NULL) {
 		argv[argc++] = shcmdp->name;
-		for (ll = car(l); ll != NULL; ll = cdr(l)) {
+		for (ll = car(l); ll != NULL; ll = cdr(ll)) {
 			if (STRING(ll))
 				argv[argc++] = (char *)ll->string;
 		}
