@@ -11,7 +11,7 @@
 #include "hostenv.h"
 #include <ctype.h>
 #include <sys/stat.h>
-#include <signal.h>
+#include "zmsignal.h"
 #include "flags.h"
 #include "malloc.h"
 #include "listutils.h"
@@ -83,11 +83,11 @@ trapsnap()
 	int i;
 
 	for (i = 1; i < NSIG; ++i)
-		orig_handler[i] = signal(i, SIG_DFL);
+		SIGNAL_HANDLESAVE(i, SIG_DFL, orig_handler[i]);
 	/* is there a vulnerability here due to SIG_DFL instead of SIG_IGN ? */
 	for (i = 1; i < NSIG; ++i)
 		if (orig_handler[i] != SIG_DFL && i != SIGCHLD)
-			signal(i, orig_handler[i]);
+			SIGNAL_HANDLE(i, orig_handler[i]);
 }
 
 /*
@@ -99,7 +99,7 @@ trap_handler(sig)
 	int sig;
 {
 	if (sig > 0 && sig < NSIG) {
-		signal(sig, trap_handler);
+		SIGNAL_HANDLE(sig, trap_handler);
 		spring[sig] += 1;
 		sprung = 1;
 	}
@@ -415,16 +415,16 @@ sh_trap(argc, argv)
 			strcpy(traps[i], script);
 			/* enable that signal */
 			if (i > 0 && orig_handler[i] != SIG_IGN)
-				signal(i, trap_handler);
+				SIGNAL_HANDLE(i, trap_handler);
 		} else if (script != NULL) {
 			traps[i] = NULL;
 			/* disable that signal */
 			if (i > 0)
-				signal(i, SIG_IGN);
+				SIGNAL_IGNORE(i);
 		} else {
 			traps[i] = NULL;
 			if (i > 0)
-				signal(i, orig_handler[i]);
+				SIGNAL_HANDLE(i, orig_handler[i]);
 		}
 	}
 	return 0;
