@@ -125,7 +125,7 @@ static struct conscell	*find_domain __((struct conscell *(*lookupfn)(), struct s
 static struct conscell	*find_nodot_domain __((struct conscell *(*lookupfn)(), struct search_info *sip));
 /* others.. */
 static void cacheflush __((struct db_info *dbip));
-static struct conscell	*readchunk __((char *file, long offset));
+extern struct conscell	*readchunk __((char *file, long offset));
 static int	iclistdbs __((struct spblk *spl));
 
 
@@ -240,6 +240,7 @@ run_relation(argc, argv)
 			dbtype);
 		return 3;
 	}
+
 	symid = symbol((u_char *)argv[optind]);
 	if (sp_lookup(symid, spt_databases) != NULL) {
 		fprintf(stderr, "%s: %s is already a defined database!\n",
@@ -256,6 +257,15 @@ run_relation(argc, argv)
 				argv[0], argv[optind]);
 		return 6;
 	}
+	if (proto_config.postproc == Indirect &&
+	    dbkp->config.owner != owner_seq) {
+		fprintf(stderr,
+			"%s: Indirect (-i) postprocessor can be used only with {un,}ordered databases!\n%s  Tried to use with: -t %s\n",
+			argv[0], argv[0], dbtype);
+		return 7;
+	}
+
+
 	if (dbkp->config.lookup == search_core
 	    || dbkp->config.lookup == search_header) {
 		/* The database name is used as a key by the incore routines */
@@ -982,114 +992,3 @@ find_nodot_domain(lookupfn, sip)
 #endif
 	return NULL;
 }
-
-static struct conscell *
-readchunk(file, offset)
-	char *file;
-	long offset;
-{
-	FILE *fp;
-	register unsigned char *cp;
-	unsigned char *as;
-	struct conscell *tmp, *l;
-	struct spblk *spl;
-	int retry, symid, flag, len;
-	char buf[BUFSIZ];
-
-	if (file == NULL || offset < 0)
-		return NULL;
-	
-	retry = 0;
-	symid = symbol((u_char *)file);
-	spl = sp_lookup(symid, spt_files);
-	if (spl == NULL || (fp = (FILE *)spl->data) == NULL) {
-reopen:
-		fp = fopen(file, "r");
-		if (fp == NULL) {
-			++deferit;
-			v_set(DEFER, DEFER_IO_ERROR);
-			fprintf(stderr, "search_seq: cannot open %s!\n", file);
-			return NULL;
-		}
-		if (spl == NULL)
-			sp_install(symid, (u_char *)fp, O_RDONLY, spt_files);
-		else
-			spl->data = (u_char *)fp;
-	}
-
-	if (fseek(fp, (long)offset, 0) != 0) {
-		++deferit;
-		v_set(DEFER, DEFER_IO_ERROR);
-		fprintf(stderr,
-			"indirect postprocessor: bad seek (%ld) on '%s'!\n",
-			(long)offset, file);
-		return NULL;
-	}
-
-	len = 0;
-	flag = 0;
-	buf[sizeof buf - 1] = '\0';
-	while (fgets(buf, sizeof buf, fp) != NULL) {
-		/* tab and space are valid continuation characters */
-		if (flag && buf[0] != '\t' && buf[0] != ' ')
-			break;
-		if (buf[sizeof buf - 1] == '\0')
-			len += strlen(buf)-1;
-		else if (buf[sizeof buf - 1] == '\n')
-			len += sizeof buf - 1;
-		else
-			len += sizeof buf;
-		flag = 1;
-	}
-
-	if (fseek(fp, (long)offset, 0) != 0) {
-		++deferit;
-		v_set(DEFER, DEFER_IO_ERROR);
-		fprintf(stderr,
-			"indirect postprocessor: bad seek (%ld) on '%s'!\n",
-			(long)offset, file);
-		return NULL;
-	}
-
-	cp = as = (u_char *)tmalloc(len+1);
-	l = NULL;
-	flag = 0;
-	buf[sizeof buf - 1] = '\0';
-	while (fgets(buf, sizeof buf, fp) != NULL) {
-		/* printaliases (actually hdr_print()) prints lines < 80 char */
-
-		if (buf[0] == '\t')
-			buf[0] = ' ';
-		else if (flag && buf[0] != ' ')
-			break;
-
-		if (buf[sizeof buf - 1] == '\0') {
-			len = strlen(buf)-1;
-			strncpy((char *)cp, buf, len);
-			cp += len;
-		} else if (buf[sizeof buf - 1] == '\n') {
-			strncpy((char *)cp, buf, sizeof buf - 1);
-			cp += sizeof buf - 1;
-		} else {
-			strncpy((char *)cp, buf, sizeof buf);
-			cp += sizeof buf;
-		}
-		flag = 1;
-	}
-	if (cp > as) {
-		*cp = 0;
-		l = newstring(as);
-	}
-	if (!retry && ferror(fp)) {
-		if (l != NULL) {
-			if (stickymem == MEM_MALLOC)
-				s_free_tree(l);
-			l = NULL;
-		}
-		fclose(fp);
-		++retry;
-		goto reopen;
-	}
-
-	return l;
-}
