@@ -661,7 +661,7 @@ rd_stability(dirp,dirs)
 			continue;
 
 		/* See that the file is a regular file! */
-		sprintf(pathbuf,"%s%s",dirs,dp->d_name);
+		sprintf(pathbuf,"%s%s%s", dirs, *dirs?"/":"", dp->d_name);
 		if (lstat(pathbuf,&statbuf) != 0) continue; /* ??? */
 		if (!S_ISREG(statbuf.st_mode)) continue; /* Hmm..  */
 
@@ -748,7 +748,7 @@ rd_instability(dirp, dirs)
 			continue;
 
 		/* See that the file is a regular file! */
-		sprintf(pathbuf,"%s%s",dirs,dp->d_name);
+		sprintf(pathbuf,"%s%s%s", dirs, *dirs?"/":"", dp->d_name);
 		if (stat(pathbuf,&statbuf) != 0) continue; /* ??? */
 		if (!S_ISREG(statbuf.st_mode)) continue; /* Hmm..  */
 
@@ -794,6 +794,7 @@ run_daemon(argc, argv)
 	char *s, *rd, *routerdirs = getzenv("ROUTERDIRS");
 	char pathbuf[256];
 	memtypes oval = stickymem;
+	struct stat stb;
 
 	SIGNAL_HANDLE(SIGTERM, sig_exit);	/* mustexit = 1 */
 	for (i=0; i<ROUTERDIR_CNT; ++i) {
@@ -808,15 +809,19 @@ run_daemon(argc, argv)
 	if (routerdirs) {
 		/* Store up secondary router dirs! */
 		rd = routerdirs;
-		for (i = 1; i < ROUTERDIR_CNT && *rd; ++i) {
+		for (i = 1; i < ROUTERDIR_CNT && *rd; ) {
 			s = strchr(rd,':');
 			if (s)  *s = 0;
 			sprintf(pathbuf,"../%s",rd);
-			strcat(pathbuf,"/");
+			/* strcat(pathbuf,"/"); */
+
+			if (stat(pathbuf,&stb) == 0  && S_ISDIR(stb.st_mode)) {
 #ifdef	BSD
-			dirp[i]->dd_size = 0;
+			  dirp[i]->dd_size = 0;
 #endif
-			dirs[i] = strsave(pathbuf);
+			  dirs[i] = strsave(pathbuf);
+			  ++i;
+			}
 			if (s)
 			  *s = ':';
 			if (s)
@@ -873,11 +878,13 @@ run_daemon(argc, argv)
 		closedir(dirp[i]);
 #endif
 		dirp[i] = opendir(dirs[i][0] == 0 ? "." : dirs[i]);
-
-		if (stability)
-			did_cnt = rd_stability(dirp[i],dirs[i]);
-		else
-			did_cnt = rd_instability(dirp[i],dirs[i]);
+		did_cnt = 0;
+		if (dirp[i] != NULL) {
+		  if (stability)
+		    did_cnt = rd_stability(dirp[i],dirs[i]);
+		  else
+		    did_cnt = rd_instability(dirp[i],dirs[i]);
+		}
 
 		if (stability != real_stability) {
 			stability = real_stability;
@@ -1415,16 +1422,9 @@ run_listexpand(avl, il)
 		int rc;
 		struct conscell *l, *d;
 
-		for (pp = ap->a_tokens; pp != NULL; pp = pp->p_next)
-			if (pp->p_type == anAddress)
-				break;
-		if (pp == NULL)
-			continue;
-		/* pureAddress(stdout, ap->a_tokens); */
-		/** printAddress(stdout, ap->a_tokens, 0); **/
-		/* putc('\n', stdout); */
 		buf[0] = 0;
-		len = printToken(buf,buf+sizeof(buf),ap->a_tokens->p_tokens, NULL, 0);
+		pureAddressBuf(buf,sizeof(buf),ap->a_tokens);
+
 		if (buf[0] == 0) continue; /* Burp ??? */
 
 #define cdddr(x) cdr(cddr(x))
