@@ -92,13 +92,19 @@ main(argc, argv)
 			break;
 		case 'm':
 #ifdef	XMEM
-			if ((fp = fopen(optarg, "w+")) != NULL) {
-				dup2(fileno(fp), 30);
-				close(fileno(fp));
-				fileno(fp) = 30;
-				mal_setstatsfile(fp);
-				mal_trace(1);
-				mal_debug(3);
+			{ /* Rewritten to be portable...  Storing to
+			     fileno()" is not guaranteed to success.. */
+			  int fd = open(optarg, O_RDWR|O_CREAT|O_TRUNC,0644);
+			  if (fd >= 0) {
+			    dup2(fd,30); /* we ASSUME have far less fd's
+					    in use.. */
+			    close(fd);
+			    fp = fdopen(30,"w+");
+			    if (!fp) break;
+			    mal_setstatsfile(fp);
+			    mal_trace(1);
+			    mal_debug(3);
+			  }
 			}
 #endif	/* XMEM */
 			break;
