@@ -202,8 +202,8 @@ hdr_rewrite(name, h)
 			}
 		}
 		if (addrtokens != NULL
-		       && addrtokens->t_next == NULL
-		       && addrtokens->t_type == String) {
+		    && addrtokens->t_next == NULL
+		    && addrtokens->t_type == String) {
 			eocp = addrtokens->t_pname + TOKENLEN(addrtokens);
 			for (cp = addrtokens->t_pname, s=buf; cp < eocp; ++cp) {
 				if (*cp == '\\' && cp < eocp - 1 && *(cp+1) == '"')
@@ -216,6 +216,7 @@ hdr_rewrite(name, h)
 		nap = (struct address *)tmalloc(sizeof (struct address));
 		nap->a_pname = NULL;
 		nap->a_stamp = newAddress;
+		nap->a_tokens = NULL;
 		/* don't bother initializing a_uid/a_mode here, no use */
 		nap->a_next = NULL;
 		nap->a_dsn  = NULL;
@@ -248,7 +249,10 @@ hdr_rewrite(name, h)
 			l = s_copy_tree(s_value);
 			s_free_tree(s_value);
 			s_value = NULL;
-			t = HDR_SCANNER(l->string);
+			/* t = HDR_SCANNER(l->string); */
+			t = scan822(&l->string, strlen(l->string),
+				    (u_char)'!', (u_char)'%',
+				    0, &ap->a_tokens->p_tokens);
 			/* X: check for errors! */
 			nap->a_tokens = mergeAddress(ap->a_tokens, t);
 		}
