@@ -12,7 +12,7 @@
 #include <sys/stat.h>
 #include <sys/param.h>
 #include <pwd.h>
-#include <mail.h>
+#include "mail.h"
 #include "scheduler.h"
 #include "malloc.h"
 #include NDIR_H
