@@ -40,6 +40,9 @@ struct sptree *spt_mesh[SIZE_L];
 struct conshell *envarlist = NULL;
 #endif	/* MALLOC_TRACE */
 
+#define TRANSPORTMAXNOFILES 32 /* Number of files a transporter may
+				  need open -- or any of its children.. */
+int	transportmaxnofiles = TRANSPORTMAXNOFILES; /* Default value */
 char	*progname;
 char	*postoffice;
 char	*rendezvous;
@@ -110,7 +113,7 @@ extern void prversion __((char *name));
 extern void qprint __((int fd));
 extern void queryipcinit __((void));
 extern void reschedule __((struct vertex *vp, int factor, int index));
-extern void syncweb __((char *dir, int nukefile, struct config_entry *ce));
+extern int  syncweb __((char *dir, int nukefile, struct config_entry *ce));
 extern void unctlfile __((struct ctlfile *cfp));
 extern void vtxdo __((struct vertex *vp, struct config_entry *ce));
 extern void vtxprint __((struct vertex *vp));
@@ -143,7 +146,7 @@ main(argc, argv)
 	daemonflg = 1;
 	dlyverbose = 0;
 	verbose = subsubdirs = errflg = version = 0;
-	while ((c = getopt(argc, argv, "disvf:L:P:Q:VW")) != EOF)
+	while ((c = getopt(argc, argv, "disvf:L:N:P:Q:VW")) != EOF)
 		switch (c) {
 		case 'f':	/* override default config file */
 			config = optarg;
@@ -151,6 +154,10 @@ main(argc, argv)
 		case 'L':	/* override default log file */
 			log = optarg;
 			break;
+		case 'N':
+			if ((transportmaxnofiles = atoi(optarg)) < 10)
+				transportmaxnofiles = TRANSPORTMAXNOFILES;
+			break;
 		case 'P':	/* override default postoffice */
 			postoffice = optarg;
 			break;
@@ -314,11 +321,14 @@ main(argc, argv)
 		  /* Delayed jobs in queue.. */
 		  vtxprep_skip_any = 0;
 		  fprintf(stderr,"Delay-sweeping previously locked files\n");
-		  syncweb(cp, 0, tp);
+		  wrkcnt = syncweb(cp, 0, tp);
 		  if (!vtxprep_skip_any) {
+		    fprintf(stderr," ... all done!\n");
 		    free(cp);
 		    cp = NULL;
-		  }
+		  } else
+		    fprintf(stderr," ... scheduled %d files successfully.\n",
+			    wrkcnt);
 		  time(&next_delaysweep);
 		  next_delaysweep += 5*60; /* Five minutes */
 		}
@@ -408,7 +418,7 @@ sig_readcf()
  * Absorb any new files that showed up in our directory.
  */
 
-void
+int
 syncweb(dir, nukefile, cehead)
 	char *dir;
 	int nukefile;
@@ -420,11 +430,12 @@ syncweb(dir, nukefile, cehead)
 	DIR *dirp;
 	struct NDIR_TYPE *dp;
 	static time_t modtime = 0;
+	int wrkcnt = 0;
 
 	if (estat(dir, &stbuf) < 0)
-	  return;
+	  return -1;
 	if (stbuf.st_mtime == modtime)
-	  return;
+	  return 0;
 	modtime = stbuf.st_mtime;
 	dirp = opendir(dir);
 	for (dp = readdir(dirp); dp != NULL; dp = readdir(dirp)) {
@@ -459,6 +470,7 @@ syncweb(dir, nukefile, cehead)
 		/* Ok, perhaps it is not in active processing, sync it in.. */
 	      }
 	      schedule(fd, file, cehead);
+	      ++wrkcnt;
 	      if (nukefile)
 		unlink(file);
 	      else		/* we're scanning TRANSPORTDIR */
@@ -485,6 +497,8 @@ syncweb(dir, nukefile, cehead)
 	close(dirp->dd_fd);
 #endif
 	closedir(dirp);
+
+	return wrkcnt;
 }
 
 /*
