@@ -20,8 +20,6 @@
 #define	FD_SETSIZE	32
 #endif	/* !FD_SETSIZE */
 
-#define TRANSPORTMAXNOFILES 32 /* Number of files a transporter may
-				  need open -- or any of its children.. */
 
 #ifdef	USE_UNIONWAIT
 #include <sys/wait.h>
@@ -37,6 +35,7 @@ struct procinfo *cpids = NULL;
 
 int	numkids = 0;
 
+extern int transportmaxnofiles;
 extern int resources_query_pipesize();
 extern char *getzenv();
 extern char *progname;
@@ -266,7 +265,7 @@ runcommand(filearr, nelem, argv, vhead, chwp, howp)
 	  close(from[0]);
 	  /* we can ignore the stdouts from other children */
 #endif
-	  resources_limit_nofiles(TRANSPORTMAXNOFILES);
+	  resources_limit_nofiles(transportmaxnofiles);
 	  setgid(gid);	/* Do GID setup while still UID 0..   */
 	  setuid(uid);	/* Now discard all excessive powers.. */
 	  execv(cmd, argv);
@@ -613,6 +612,7 @@ queryipcinit()
 	time_t now;
 	struct servent *serv;
 	struct sockaddr_in sad;
+	int on = 1;
 
 	if (querysocket >= 0)
 		return;
@@ -631,6 +631,8 @@ queryipcinit()
 	  perror("socket");
 	  return;
 	}
+	setsockopt(querysocket, SOL_SOCKET, SO_REUSEADDR, &on, sizeof(on));
+
 	if (bind(querysocket, (struct sockaddr *)&sad, sizeof sad) < 0) {
 	  perror("bind");
 	  close(querysocket);
