@@ -9,7 +9,7 @@
 #include <syslog.h>
 #include <sys/param.h>
 #include <sys/stat.h>
-#include <mail.h>
+#include "mail.h"
 #include "scheduler.h"
 #include NDIR_H
 
