@@ -1193,6 +1193,7 @@ smtpserver(insecure)
 	time_t now;
 	long tell, filsiz;
 	int inum;
+	int bad8bithdr;
 	struct stat stbuf;
 	struct sockaddr_in localsock;
 	int localsocksize;
@@ -1387,7 +1388,8 @@ smtpserver(insecure)
 			}
 			type(354, (char *)NULL);
 			alarm(60*60*24);	/* one day should be enough! */
-			filsiz = mvdata(mfp);
+			bad8bithdr = 0;
+			filsiz = mvdata(mfp,&bad8bithdr);
 			alarm(0);	/* cancel alarm */
 			tell = ftell(mfp);
 			if (fstat(fileno(mfp), &stbuf) < 0)
@@ -1395,7 +1397,10 @@ smtpserver(insecure)
 			else
 				inum = stbuf.st_ino;
 
-			if (feof(stdin) || ferror(stdin)) {
+			if (bad8bithdr) {
+				mail_abort(mfp);
+				type(452,"Message header had 8-bit character(s) outside Subject!");
+			} else if (feof(stdin) || ferror(stdin)) {
 				/* [mea@utu.fi] says this can happen */
 				mail_abort(mfp);
 				reporterr(tell, "premature EOF on DATA input");
@@ -2129,8 +2134,9 @@ static int	indexnum[256+1] = {
  */
 
 int /* count of bytes */
-mvdata(out)
+mvdata(out,bad8bitp)
 	register FILE *out;
+	int *bad8bitp;
 {
 	register FILE *input;
 	register int c, state, *idxnum, *sts, endstate, cnt;
@@ -2146,6 +2152,9 @@ mvdata(out)
 #else
 	char linebuf[2000], *s, *eol;
 	int col;
+	int insubject = 0;
+	int has8bit = 0; /* In headers */
+	int has8bitsum = 0;
 
 	idxnum = indexnum+1;
 
@@ -2158,13 +2167,15 @@ mvdata(out)
 
 	/* ================ Input the email headers ================ */
 	/*	     and analyze them a bit (Precedence:)	     */
+	/*	  ... that only "Subject:" has 8-bit chars ...	     */
 	mail_priority = _MAILPRIO_NORMAL;
 	for (;;) {
 		c = getc(input);
 		/* An EOF in here is an error! */
 #if EOF != -1
-		if (c == EOF) return cnt;
+		if (c == EOF) return EOF;
 #endif
+		if (0x80 & c) has8bit = 1;
 		if ((state = sts[state+idxnum[c]]) & ~0xff) {
 			if (state & O_) {
 				if (state == endstate)
@@ -2202,6 +2213,13 @@ mvdata(out)
 			continue;	/* continuation line.. */
 
 		/* ================ PROCESS THE HEADERS! ================ */
+		if (strncasecmp(linebuf,"Subject:",8)==0) {
+			insubject = 1;
+		} else {
+			if (!insubject)
+				has8bitsum += has8bit;
+		}
+		has8bit = 0;
 		if (strncasecmp(linebuf,"Precedence:",11)==0) {
 			s = linebuf+11;
 			while (*s == ' ' || *s == '\t') ++s;
@@ -2223,7 +2241,7 @@ mvdata(out)
 		c = getc(input);
 #if EOF != -1
 		if (c == EOF)		/* a little slower... */
-			return cnt;
+			return EOF;
 #endif
 		++cnt;
 		if ((state = sts[state+idxnum[c]]) & ~0xff) {
@@ -2240,6 +2258,7 @@ mvdata(out)
 		if (!ferror(out))
 		  putc(c, out);
 	}
+	*bad8bitp = has8bitsum;
 	return cnt;
 }
 
