@@ -8,13 +8,13 @@
 #include <ctype.h>
 #include "malloc.h"
 #include <pwd.h>
-#include <signal.h>
 #include <sysexits.h>
 #include <varargs.h>
 #include <fcntl.h>
 #include <sys/param.h>
 #include <sys/stat.h>
-#include <mail.h>
+#include "mail.h"
+#include "zmsignal.h"
 #include "ta.h"
 #include NDIR_H
 
@@ -28,6 +28,7 @@ char *dfltform[] = {
 		"Cc: The Postmaster <postmaster>",
 		"MIME-Version: 1.0",
 		"Content-Type: multipart/report; report-type=delivery-status;",
+		"Precedence: junk", /* BSD sendmail */
 		"",
 		"Processing your mail message caused the following errors:",
 		NULL
@@ -58,14 +59,18 @@ main(argc, argv)
 	char *channel, file[MAXPATHLEN+1];
 	int errflg, c;
 	struct ctldesc *dp;
+	SIGNAL_TYPE (*oldsig)();
 
-	if (signal(SIGINT, SIG_IGN) != SIG_IGN)
-	  signal(SIGINT, wantout);
-	if (signal(SIGHUP, SIG_IGN) != SIG_IGN)
-	  signal(SIGHUP, wantout);
-	if (signal(SIGTERM, SIG_IGN) != SIG_IGN)
-	  signal(SIGTERM, wantout);
-	signal(SIGPIPE, SIG_IGN);
+	SIGNAL_HANDLESAVE(SIGINT, SIG_IGN, oldsig);
+	if (oldsig != SIG_IGN)
+	  SIGNAL_HANDLE(SIGINT, wantout);
+	SIGNAL_HANDLESAVE(SIGHUP, SIG_IGN, oldsig);
+	if (oldsig != SIG_IGN)
+	  SIGNAL_HANDLE(SIGHUP, wantout);
+	SIGNAL_HANDLESAVE(SIGTERM, SIG_IGN, oldsig);
+	if (oldsig != SIG_IGN)
+	  SIGNAL_HANDLE(SIGTERM, wantout);
+	SIGNAL_IGNORE(SIGPIPE);
 
 	if ((progname = strrchr(argv[0], '/')) == NULL)
 	  progname = argv[0];
