@@ -11,7 +11,7 @@
 #include "hostenv.h"
 #include <sysexits.h>
 #include <varargs.h>
-#include <mail.h>
+#include "mail.h"
 #include "ta.h"
 
 
@@ -89,7 +89,6 @@ diagnostic(va_alist) /* (rp, rc, "fmtstr", remotemsg) */
 	char	mark, message[8192];
 	register char *cp, *s, *es, *s2;
 	va_list	ap;
-	extern int lockaddr();
 
 	va_start(ap);
 	rp = va_arg(ap, struct rcpt *);		/* arg1: rp */
