@@ -517,7 +517,8 @@ char **cte_linep;	/* Propably is not a multiline entry.. */
 
 /*
  *  Check for  "Content-conversion: prohibited" -header, and return
- *  non-zero when found it.
+ *  non-zero when found it. ---  eh, "-1", return '7' when QP-coding
+ *  is mandated.. (test stuff..)
  */
 int
 check_conv_prohibit(rp)
@@ -530,7 +531,8 @@ struct rcpt *rp;
 	  if (cistrncmp(*hdrs,"Content-conversion:", 19)==0) {
 	    char *s = *hdrs + 19;
 	    while (*s == ' ' || *s == '\t') ++s;
-	    return (cistrncmp(s,"prohibited",10)==0);
+	    if (cistrncmp(s,"prohibited",10)==0) return -1;
+	    if (cistrncmp(s,"forced-qp",9)==0) return 7;
 	    /* Prohibits (?) the content conversion.. */
 	  }
 	  ++hdrs;
