@@ -406,11 +406,11 @@ main(argc, argv)
 	}
 #ifdef	RBIFF
 	if (spt_users != NULL) {
-	  readrwho();
-	  for (nbp = biffs ; nbp != NULL; nbp = nbp->next) {
-	    if (nbp->offset >= 0 && nbp->wantrbiff)
-	      rbiff(nbp);
-	  }
+	  if (readrwho())
+	    for (nbp = biffs ; nbp != NULL; nbp = nbp->next) {
+	      if (nbp->offset >= 0 && nbp->wantrbiff)
+		rbiff(nbp);
+	    }
 	}
 #endif	/* RBIFF */
 #endif	/* BIFF || RBIFF */
@@ -1509,7 +1509,8 @@ appendlet(dp, rp, fp, file, ismime)
 	int ismime;
 	char *file;
 {
-	int lastch = -1;
+	int lastch = 0xFFF; /* Something no character can be,
+			       and not "-1" either.. */
 #ifndef	USE_MMAP
 	static char buffer[BUFSIZ+1];
 	static char *bufend = buffer+BUFSIZ;
@@ -1713,6 +1714,7 @@ biff(hostname, username, offset)
 
 
 #ifdef RBIFF
+int
 readrwho()
 {
 	struct whod wd;
@@ -1736,8 +1738,12 @@ readrwho()
 	  return;
 	now = time(0);
 	if (chdir(RWHODIR) || (dirp = opendir(".")) == NULL ) {
-	  perror(RWHODIR);
-	  exit(EX_OSFILE);
+	  /* BE SILENT -- failing RBIFF is no fault! */
+	  return 0;
+	  /*
+	     perror(RWHODIR);
+	     exit(EX_OSFILE);
+	   */
 	}
 	while (dp = readdir(dirp)) {
 	  if (dp->d_ino == 0
@@ -1777,6 +1783,7 @@ readrwho()
 	  close(f);
 	}
 	closedir(dirp);
+	return 1;
 }
 
 void
