@@ -40,6 +40,7 @@ char uucpname[MAXHOSTNAMELEN+1];
 char	*progname;
 int	readalready = 0;	/* does buffer contain valid message data? */
 int	can_8bit = 0;		/* Can do 8-bit stuff! */
+int	mimeqpnarrow = 0;	/* Can't send TAB thru without MIME-QP */
 FILE	*verboselog = NULL;
 FILE	*logfp   = NULL;
 int	maxwidth = 0;
@@ -148,7 +149,7 @@ main(argc, argv)
 	errflg = 0;
 	host = channel = NULL;
 	cf = NULL;
-	while ((c = getopt(argc, argv, "f:c:h:vVw:8")) != EOF) {
+	while ((c = getopt(argc, argv, "f:c:h:QvVw:8")) != EOF) {
 	  switch (c) {
 	  case 'f':
 	    cf = optarg;
@@ -159,6 +160,9 @@ main(argc, argv)
 	  case 'h':		/* remote hostname */
 	    host = optarg;
 	    break;
+	  case 'Q':
+	    mimeqpnarrow = 1;
+	    break;
 	  case 'V':
 	    prversion("sm");
 	    exit(0);
@@ -180,7 +184,7 @@ main(argc, argv)
 	}
 	if (errflg || optind != argc - 1 || host == channel) {
 	  fprintf(stderr,
-		  "Usage: %s [-c channel || -h host] mailer\n", argv[0]);
+		  "Usage: %s [-V][-v][-8 || -Q][-f cfgfile][-w maxwidth][-c channel || -h host] mailer\n", argv[0]);
 	  exit(EX_USAGE);
 	}
 	mailer = argv[optind];
@@ -830,9 +834,17 @@ writemimeline(mp, fp, buf, len, convertmode, lastchp)
 	      /* We Q-P encode the leading 'F'.. */
 	      if (fputs("=46",fp) != 3) return EOF;
 	      column += 2;
-	    } else if (c != '\n' && (c < 32 || c > 126 || c == '=')) {
+	    } else if ((n < 3 || mimeqpnarrow) && c != '\n' &&
+		       (c <= 32 || c > 126 || c == '=')) {
 	      /* Downgrade it by translating it to Quoted-Printable.. */
-	      fprintf(fp,"=%02X",c);
+	      /* Translate also trailing spaces/TABs */
+	      if (fprintf(fp,"=%02X",c) != 3) return EOF;
+	      column += 2;
+	    } else if (c != '\n' && c != '\t' &&
+		       (c < 32 || c > 126 || c == '=')) {
+	      /* Downgrade it by translating it to Quoted-Printable.. */
+	      /* SPACE and TAB are left untranslated */
+	      if (fprintf(fp,"=%02X",c) != 3) return EOF;
 	      column += 2;
 	      buf = cp;
 	    } else if (c == '\n') { /* This is most likely the LAST char */
