@@ -536,7 +536,7 @@ deliver(dp, smtpfp, verboselog, startrp, endrp)
 	char *s;
 	int conv_prohibit = check_conv_prohibit(startrp);
 
-	if (conv_prohibit) {
+	if (conv_prohibit < 0) {
 	  convertmode = _CONVERT_NONE;
 	} else {
 
@@ -551,6 +551,9 @@ deliver(dp, smtpfp, verboselog, startrp, endrp)
 	      content_kind = 7;
 	  }
 
+	  if (conv_prohibit == 7)
+	    force_7bit = 1;
+
 	  if (force_7bit)	/* Mark off the 8BIT MIME capability.. */
 	    ehlo_capabilities &= ~ESMTP_8BITMIME;
 
@@ -1048,9 +1051,10 @@ writemimeline(fp, buf, len, convertmode, lastcharp)
 	    }
 	    if (qp_chrs != 0) {
 	      if (c == ' ' || c == '\t' || c == '\n' || c == '\r') {
-		n = 0;	/* We have the line-end wrapper mode */
-		continue; /* It should NEVER be present except at the end
-			     of the line, thus we are safe to do this ? */
+		n = 0;		/* We have the line-end wrapper mode */
+		continue;	/* It should NEVER be present except at
+				   the end of the line, thus we are safe
+				   to do this ? */
 	      }
 	      --column;
 	      if ((c >= '0' && c <= '9') ||
@@ -1071,8 +1075,8 @@ writemimeline(fp, buf, len, convertmode, lastcharp)
 		continue;
 	    }
 	    *lastcharp = c;
-	  } else {
-	    if (qp_conv && column > 70 && c != '\n') {
+	  } else if (qp_conv) {
+	    if (column > 70 && c != '\n') {
 	      putc('=',fp);
 	      putc('\r',fp);
 	      putc('\n',fp);
@@ -1080,18 +1084,29 @@ writemimeline(fp, buf, len, convertmode, lastcharp)
 	      /* if (verboselog) fprintf(verboselog,"=\n"); */
 	      column = -1;
 	    }
-	    if (qp_conv &&
-		(c == '='  ||  c > 126 ||  (c != '\n' && c < 32))) {
+	    /* Trailing SPACE/TAB ? */
+	    if (n < 3 && (c == ' ' || c == '\t')) {
+	      putc('=',fp);
+	      putc(i2h[(c >> 4) & 15],fp);
+	      putc(i2h[(c)      & 15],fp);
+	      *lastcharp = i2h[(c) & 15];
+	      column += 2;
+	      /* if (verboselog) fprintf(verboselog,"=%02X",c); */
+	      continue;
+	    }
+	    /* Any other char which needs quoting ? */
+	    if (c == '='  ||  c > 126 ||
+		(c != '\n' && c != '\t' && c < 32)) {
 
 	      putc('=',fp);
 	      putc(i2h[(c >> 4) & 15],fp);
 	      putc(i2h[(c)      & 15],fp);
 	      *lastcharp = i2h[(c) & 15];
-	      column += 3;
+	      column += 2;
 	      /* if (verboselog) fprintf(verboselog,"=%02X",c); */
 	      continue;
 	    }
-	  }
+	  } /* .... end convertmode	*/
 
 	  if (column == 0 && c == '.') {
 	    if (putc(c, fp) == EOF) {
